# nbcx
A framework for building reports with [nbconvert](https://nbconvert.readthedocs.io).

[![Build Status](https://github.com/timkpaine/nbcx/workflows/Build%20Status/badge.svg?branch=main)](https://github.com/timkpaine/nbcx/actions?query=workflow%3A%22Build+Status%22)
[![Coverage](https://codecov.io/gh/timkpaine/nbcx/branch/main/graph/badge.svg?token=ag2j2TV2wE)](https://codecov.io/gh/timkpaine/nbcx)
[![GitHub issues](https://img.shields.io/github/issues/timkpaine/nbcx.svg)](https://github.com/timkpaine/nbcx/issues)
[![PyPI](https://img.shields.io/pypi/l/nbcx.svg)](https://pypi.python.org/pypi/nbcx)
[![PyPI](https://img.shields.io/pypi/v/nbcx.svg)](https://pypi.python.org/pypi/nbcx)
